@@ -59,7 +59,8 @@ struct BirdEyeViewPrivate
     QPropertyAnimation* mOpacityAnim;
     QTimer* mAutoHideTimer;
     QRectF mVisibleRect;
-    QPointF mLastDragPos;
+    QPointF mStartDragMousePos;
+    QPointF mStartDragViewPos;
 
     void updateCursor(const QPointF& pos)
     {
@@ -78,7 +79,7 @@ struct BirdEyeViewPrivate
         } else if (mVisibleRect == q->boundingRect()) {
             // All of the image is visible
             visible = false;
-        } else if (q->isUnderMouse() || !mLastDragPos.isNull()) {
+        } else if (q->isUnderMouse() || !mStartDragMousePos.isNull()) {
             // User is interacting or about to interact with birdeyeview
             visible = true;
         } else if (mAutoHideTimer->isActive()) {
@@ -138,9 +139,17 @@ void BirdEyeView::adjustGeometry()
     if (!d->mDocView->canZoom() || d->mDocView->zoomToFit()) {
         return;
     }
-    QSize size = d->mDocView->document()->size();
+    QSizeF size = d->mDocView->document()->size();
     size.scale(MIN_SIZE, MIN_SIZE, Qt::KeepAspectRatioByExpanding);
     QRectF docViewRect = d->mDocView->boundingRect();
+    int maxBevHeight = docViewRect.height() - 2 * VIEW_OFFSET;
+    int maxBevWidth = docViewRect.width() - 2 * VIEW_OFFSET;
+    if (size.height() > maxBevHeight) {
+        size.scale(MIN_SIZE, maxBevHeight, Qt::KeepAspectRatio);
+    }
+    if (size.width() > maxBevWidth) {
+        size.scale(maxBevWidth, MIN_SIZE, Qt::KeepAspectRatio);
+    }
     QRectF geom = QRectF(
         QApplication::isRightToLeft()
         ? docViewRect.left() + VIEW_OFFSET
@@ -157,7 +166,13 @@ void BirdEyeView::adjustVisibleRect()
 {
     QSizeF docSize = d->mDocView->document()->size();
     qreal viewZoom = d->mDocView->zoom();
-    qreal bevZoom = size().width() / docSize.width();
+    qreal bevZoom;
+    if (docSize.height() > docSize.width()) {
+        bevZoom = size().height() / docSize.height();
+    } else {
+        bevZoom = size().width() / docSize.width();
+    }
+
     if (qFuzzyIsNull(viewZoom) || qFuzzyIsNull(bevZoom)) {
         // Prevent divide-by-zero crashes
         return;
@@ -166,7 +181,7 @@ void BirdEyeView::adjustVisibleRect()
     QRectF rect = QRectF(
         QPointF(d->mDocView->position()) / viewZoom * bevZoom,
         (d->mDocView->size() / viewZoom).boundedTo(docSize) * bevZoom);
-    d->mVisibleRect = alignedRectF(rect);
+    d->mVisibleRect = rect;
 }
 
 void BirdEyeView::slotAutoHideTimeout()
@@ -227,34 +242,34 @@ void BirdEyeView::mousePressEvent(QGraphicsSceneMouseEvent* event)
 {
     if (d->mVisibleRect.contains(event->pos())) {
         setCursor(Qt::ClosedHandCursor);
-        d->mLastDragPos = event->pos();
+        d->mStartDragMousePos = event->pos();
+        d->mStartDragViewPos = d->mDocView->position();
     }
 }
 
 void BirdEyeView::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
 {
     QGraphicsItem::mouseMoveEvent(event);
-    if (d->mLastDragPos.isNull()) {
+    if (d->mStartDragMousePos.isNull()) {
         // Do not drag if mouse was pressed outside visible rect
         return;
     }
-    qreal ratio = d->mDocView->boundingRect().width() / d->mVisibleRect.width();
-
+    qreal ratio = qMin(d->mDocView->boundingRect().height() / d->mVisibleRect.height(),
+                       d->mDocView->boundingRect().width() / d->mVisibleRect.width());
     QPointF mousePos = event->pos();
-    QPointF viewPos = d->mDocView->position() + (mousePos - d->mLastDragPos) * ratio;
+    QPointF viewPos = d->mStartDragViewPos + (mousePos - d->mStartDragMousePos) * ratio;
 
-    d->mLastDragPos = mousePos;
     d->mDocView->setPosition(viewPos.toPoint());
 }
 
 void BirdEyeView::mouseReleaseEvent(QGraphicsSceneMouseEvent* event)
 {
     QGraphicsItem::mouseReleaseEvent(event);
-    if (d->mLastDragPos.isNull()) {
+    if (d->mStartDragMousePos.isNull()) {
         return;
     }
     d->updateCursor(event->pos());
-    d->mLastDragPos = QPointF();
+    d->mStartDragMousePos = QPointF();
     d->mAutoHideTimer->start();
 }
 
@@ -266,7 +281,7 @@ void BirdEyeView::hoverEnterEvent(QGraphicsSceneHoverEvent* /*event*/)
 
 void BirdEyeView::hoverMoveEvent(QGraphicsSceneHoverEvent* event)
 {
-    if (d->mLastDragPos.isNull()) {
+    if (d->mStartDragMousePos.isNull()) {
         d->updateCursor(event->pos());
     }
 }
