@@ -31,7 +31,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 namespace Gwenview
 {
 
-class ContextBarButtonPrivate;
+struct ContextBarButtonPrivate;
 /**
  * A button with a special look, appears when hovering over thumbnails
  */
